@@ -22,6 +22,7 @@ Function pointer for the appropriate relaxation method for level=lvl
 Examples
 --------
 See change_smoothers above
+
 """
 
 from functools import partial, update_wrapper
@@ -369,11 +370,12 @@ def change_smoothers(ml, presmoother, postsmoother):
 
 
 def rho_D_inv_A(A):
-    """Return the (approx.) spectral radius of D^-1 * A.
+    """Return the (approx.) spectral radius of D^-1 @ A.
 
     Parameters
     ----------
-    A : sparse-matrix
+    A : sparse matrix
+        Target matrix for computing the spectral radius
 
     Returns
     -------
@@ -383,9 +385,9 @@ def rho_D_inv_A(A):
     --------
     >>> from pyamg.gallery import poisson
     >>> from pyamg.relaxation.smoothing import rho_D_inv_A
-    >>> from scipy.sparse import csr_matrix
+    >>> from scipy.sparse import csr_array
     >>> import numpy as np
-    >>> A = csr_matrix(np.array([[1.0,0,0],[0,2.0,0],[0,0,3.0]]))
+    >>> A = csr_array(np.array([[1.0,0,0],[0,2.0,0],[0,0,3.0]]))
     >>> print(f'{rho_D_inv_A(A):2.2}')
     1.0
 
@@ -399,7 +401,7 @@ def rho_D_inv_A(A):
 
 
 def rho_block_D_inv_A(A, Dinv):
-    """Return the (approx.) spectral radius of block D^-1 * A.
+    """Return the (approx.) spectral radius of block D^-1 @ A.
 
     Parameters
     ----------
@@ -431,14 +433,14 @@ def rho_block_D_inv_A(A, Dinv):
         if Dinv.shape[0] != int(A.shape[0]/blocksize):
             raise ValueError('Dinv and A have incompatible dimensions')
 
-        Dinv = sparse.bsr_matrix((Dinv,
-                                  np.arange(Dinv.shape[0]),
-                                  np.arange(Dinv.shape[0]+1)),
-                                 shape=A.shape)
+        Dinv = sparse.bsr_array((Dinv,
+                                 np.arange(Dinv.shape[0], dtype=np.int32),
+                                 np.arange(Dinv.shape[0] + 1, dtype=np.int32)),
+                                shape=A.shape)
 
-        # Don't explicitly form Dinv*A
+        # Don't explicitly form Dinv @ A
         def matvec(x):
-            return Dinv*(A*x)
+            return Dinv @ (A @ x)
         D_inv_A = LinearOperator(A.shape, matvec, dtype=A.dtype)
 
         A.rho_block_D_inv = approximate_spectral_radius(D_inv_A)
@@ -552,9 +554,9 @@ def setup_block_jacobi(lvl, iterations=DEFAULT_NITER, omega=1.0, Dinv=None,
     """Set up block Jacobi."""
     # Determine Blocksize
     if blocksize is None and Dinv is None:
-        if sparse.isspmatrix_csr(lvl.A):
+        if sparse.issparse(lvl.A) and lvl.A.format == 'csr':
             blocksize = 1
-        elif sparse.isspmatrix_bsr(lvl.A):
+        elif sparse.issparse(lvl.A) and lvl.A.format == 'bsr':
             blocksize = lvl.A.blocksize[0]
     elif blocksize is None:
         blocksize = Dinv.shape[1]
@@ -583,9 +585,9 @@ def setup_block_gauss_seidel(lvl, iterations=DEFAULT_NITER,
     """Set up block Gauss-Seidel."""
     # Determine Blocksize
     if blocksize is None and Dinv is None:
-        if sparse.isspmatrix_csr(lvl.A):
+        if sparse.issparse(lvl.A) and lvl.A.format == 'csr':
             blocksize = 1
-        elif sparse.isspmatrix_bsr(lvl.A):
+        elif sparse.issparse(lvl.A) and lvl.A.format == 'bsr':
             blocksize = lvl.A.blocksize[0]
     elif blocksize is None:
         blocksize = Dinv.shape[1]
@@ -709,12 +711,12 @@ def setup_cf_block_jacobi(lvl, f_iterations=DEFAULT_NITER, c_iterations=DEFAULT_
     """Set up coarse-fine block Jacobi."""
     # Determine Blocksize
     if blocksize is None and Dinv is None:
-        if sparse.isspmatrix_csr(lvl.A):
+        if sparse.issparse(lvl.A) and lvl.A.format == 'csr':
             blocksize = 1
-        elif sparse.isspmatrix_bsr(lvl.A):
+        elif sparse.issparse(lvl.A) and lvl.A.format == 'bsr':
             blocksize = lvl.A.blocksize[0]
     elif blocksize is None:
-        if sparse.isspmatrix_bsr(Dinv):
+        if sparse.issparse(Dinv) and Dinv.format == 'bsr':
             blocksize = Dinv.blocksize[1]
         else:
             blocksize = 1
@@ -752,12 +754,12 @@ def setup_fc_block_jacobi(lvl, f_iterations=DEFAULT_NITER, c_iterations=DEFAULT_
     """Set up coarse-fine block Jacobi."""
     # Determine Blocksize
     if blocksize is None and Dinv is None:
-        if sparse.isspmatrix_csr(lvl.A):
+        if sparse.issparse(lvl.A) and lvl.A.format == 'csr':
             blocksize = 1
-        elif sparse.isspmatrix_bsr(lvl.A):
+        elif sparse.issparse(lvl.A) and lvl.A.format == 'bsr':
             blocksize = lvl.A.blocksize[0]
     elif blocksize is None:
-        if sparse.isspmatrix_bsr(Dinv):
+        if sparse.issparse(Dinv) and Dinv.format == 'bsr':
             blocksize = Dinv.blocksize[1]
         else:
             blocksize = 1
@@ -882,12 +884,14 @@ def rebuild_smoother(lvl):
     Parameters
     ----------
     lvl : Level object
+        Single level of the hierarchy
 
     Notes
     -----
     This rebuilds a smoother on level lvl using the existing pre
     and post smoothers.  If different methods are needed, see
     `change_smoothers`.
+
     """
     try:
         fn1 = lvl.presmoother.__name__
